@@ -5,7 +5,8 @@ from typing import Callable, List, Optional, Tuple
 from pydantic import BaseModel
 from sanic import HTTPResponse, Request, Sanic
 
-from services.db.sqlhelper import AsyncSQL
+from services.db import AsyncSQL
+from services.security import Authenticator, IAuth
 from services.types import Settings
 
 
@@ -40,15 +41,23 @@ class WebAppSpec(ABC):
 
     name: str
     views: List[ViewSet]
-    bp_modules: List[str]
-    package_dir: str
-    # middlewares: List[Tuple[str, Callable]]
-    # dependencies: List[Callable]
+    auth: Authenticator
+
+    #    self.auth: Authenticator = Authenticator()
+    def __init__(self, app: Sanic, settings: Settings):
+        self.auth: Authenticator = Authenticator()
+        app.ctx.auth_beta = self.auth
+        self.app = app
+        self.init(app, settings)
 
     @abstractmethod
     def init(self, app: Sanic, settings: Settings):
         pass
 
+    def register_auth_validator(self, app: Sanic, name: str, auth: IAuth):
+        app.ext.dependency(auth)
+        self.auth.register_validator(name, auth)
+
     def init_blueprints(self, app: Sanic):
         for view in self.views:
             _init_blueprints(app, view.blueprints, package_dir=view.package)
@@ -62,25 +71,5 @@ class WebAppSpec(ABC):
     def get_request_settings(self, request: Request) -> Settings:
         return request.app.config.SETTINGS
 
-
-class PluginSpec(ABC):
-    name: str
-    request_ctx_name: Optional[str] = None
-    request_hook_enabled: bool = False
-    response_hook_enabled: bool = False
-
-    @abstractmethod
-    def init(self, app: Sanic, settings: Settings):
-        pass
-
-    def get_from_request(self, request):
-        obj = getattr(request.app.ctx, self.name)
-        return obj
-
-    @abstractmethod
-    async def request_hook(self, request: Request):
-        raise NotImplementedError("Response hook not implemented")
-
-    @abstractmethod
-    async def response_hook(self, request: Request, response: HTTPResponse):
-        raise NotImplementedError("Response hook not implemented")
+    def get_request_auth(self, request: Request) -> Authenticator:
+        return request.app.ctx.auth_beta
