@@ -2,8 +2,13 @@
 # pylint: disable=line-too-long
 from typing import Any, Callable, Dict, List, Optional, Type, Union
 
-from jinja2 import (Environment, FileSystemLoader, PackageLoader, Template,
-                    select_autoescape)
+from jinja2 import (
+    Environment,
+    FileSystemLoader,
+    PackageLoader,
+    Template,
+    select_autoescape,
+)
 from jinja2.ext import Extension
 from sanic import Sanic
 from services.types import Settings
@@ -85,11 +90,13 @@ class Render:
         dev_server = f"{conf.VITE_DEV_SERVER}"
         if conf.VITE_BASE != "/":
             dev_server = f"{conf.VITE_DEV_SERVER}{conf.VITE_BASE}"
-        self.add_extension(ViteDev)
-        self.add_extension(ViteAsset)
+
         self.env.vite_dev_server = dev_server
         self.env.vite_dev_mode = conf.VITE_DEV_MODE
         self.env.vite_react_mode = conf.VITE_REACT_MODE
+        self.env.vite_base = conf.VITE_BASE
+        self.add_extension(ViteDev)
+        self.add_extension(ViteAsset)
 
         if conf.VITE_DEV_MODE:
             static_dir = f"{settings.BASE_PATH}/{conf.VITE_STATIC_DIR}"
@@ -110,12 +117,36 @@ class Render:
         app.ctx.render = self
         self.env.globals.update(url_for=app.url_for)
 
+    def _get_app(self, request) -> Sanic:
+        return request.app
+
     async def async_render(self, request, tpl_name, **kwargs) -> str:
         template = self.env.get_template(tpl_name)
-        ctx = {
-            "request": request.ctx.__dict__,
-        }
-        rendered = await template.render_async(ctx, **kwargs)
+        app = self._get_app(request)
+        conf = {}
+        ctx = {}
+        if app.config.SETTINGS.DEBUG:
+            ctx = {
+                "request": request.ctx.__dict__,
+            }
+            conf = app.config.SETTINGS
+        rendered = await template.render_async(conf=conf, ctx=ctx, **kwargs)
+        return rendered
+
+    async def arender(self, tpl_name, **kwargs) -> str:
+        template = self.env.get_template(tpl_name)
+        # ctx = {
+        #     "request": request.ctx.__dict__,
+        # }
+        rendered = await template.render_async(**kwargs)
+        return rendered
+
+    def render(self, tpl_name, **kwargs) -> str:
+        template = self.env.get_template(tpl_name)
+        # ctx = {
+        #     "request": request.ctx.__dict__,
+        # }
+        rendered = template.render(**kwargs)
         return rendered
 
     def get_template(self, tpl_name) -> Template:
