@@ -1,4 +1,6 @@
+import os
 from dataclasses import dataclass
+from datetime import datetime
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 
@@ -16,8 +18,8 @@ class StaticDir(BaseModel):
 class Database(BaseModel):
     """
     Database configuration object to be used with
-    :class:`services.db.sqlhelper.SQL` and
-    :class:`services.db.sqlhelper.AsyncSQL`
+    :class:`services.db.SQL` and
+    :class:`services.db.AsyncSQL`
 
     Examples:
 
@@ -57,6 +59,16 @@ class MigrationType(BaseModel):
     version_table: str
 
 
+class TasksBackend(BaseModel):
+    uri: str = "sqlite+aiosqlite:///tasks.db"
+    backend_class: str = "services.ext.sql.workers.SQLBackend"
+
+
+class Storage(BaseModel):
+    bucket: str = ".storage"
+    store_class: str = "services.storage.AsyncLocal"
+
+
 class SecuritySettings(BaseSettings):
     JWT_PUBLIC: Optional[str] = None
     JWT_PRIVATE: Optional[str] = None
@@ -64,7 +76,6 @@ class SecuritySettings(BaseSettings):
     JWT_ALG: str = "ES512"
     JWT_EXP: int = 30  # 30 minutes
     JWT_CLAIMS_REQUIRED: List[str] = ["exp"]
-    JWT_SECRET: Optional[str] = None
     JWT_ISS: Optional[str] = None
     JWT_AUD: Optional[str] = None
     REFRESH_TOKEN_TTL: int = 3600 * 168  # 7 days
@@ -142,51 +153,20 @@ class ViteConfig(BaseModel):
     VITE_BASE: str = "/"
 
 
-class Settings(BaseSettings):
-    BASE_PATH: Union[str, Path]
-    HOST: str = "localhost"
-    PORT: str = "8000"
-    DATABASES: Dict[str, Database] = {}
-    REDIS: Optional[RedisDsn] = None
-    REDIS_POOL_SIZE: int = 10
-    TEMPLATES_DIR: List[str] = Field(default_factory=list)
-    TEMPLATES_PACKAGE_NAME: Optional[str] = None
-    DEV_MODE: bool = False
-    SECURITY: Optional[SecuritySettings] = None
-    CUSTOM_COMMANDS: List[str] = []
-    USER_ENDPOINTS: bool = True
-    USER_MODEL: Optional[str] = None
-    USER_DB: str = "default"
-    USER_MANAGER_CLASS = "services.user.managers.UserManager"
-
-    APPS: List[str] = []
-
-    # web
-    STATIC_URL: str = ""
-    STATICFILES_DIRS: List[StaticDir] = Field(default_factory=list)
-    VITE_ENABLED: bool = False
-    VITE_CONFIG: ViteConfig = ViteConfig()
-    # logs
-    LOGLEVEL: str = "INFO"
-    LOGCONFIG: Dict[str, Any] = {}
-    DEBUG: bool = False
-
-    # MIGRATIONS: Dict[str, Migration] = {}
-
-    CORS_ORIGINS: Union[List, str] = "*"
-    CORS_ALLOW_HEADERS: Union[List, str] = "*"
-    SANIC_APP_NAME = defaults.SANIC_APP
-    SETTINGS_MODULE: Optional[str] = None
-
-    class Config:
-        env_prefix = "SRV_"
-
-
 class KeyPairs(BaseModel):
     public: str
     private: str
 
 
+class JWTPayload(BaseModel):
+    exp: Optional[int] = None
+    iat: Optional[int] = None
+    iss: Optional[str] = None
+    sub: Optional[str] = None
+    aud: Optional[str] = None
+    custom: Dict[str, Any] = Field(default={})
+
+
 class JWTConfig(BaseModel):
     alg: str
     exp_min: int = 30
@@ -196,11 +176,69 @@ class JWTConfig(BaseModel):
     audience: Optional[str] = None
     requires_claims: List[str] = ["exp"]
     ttl_refresh_token: int = 3600 * 168  # 7 days
+    allow_refresh_token: bool = False
 
     class Config:
         extra = "forbid"
 
 
+class SecurityConfig(BaseModel):
+    secret_key: str
+    jwt: Optional[JWTConfig] = None
+    session: Optional[str] = None
+    token_store_uri: str = "sqlite+aiosqlite:///:memory:"
+    authenticators: List[str] = Field([])
+    ttl_refresh_token: int = 3600 * 168  # 7 days
+    domain: str = "localhost"
+
+
+class Settings(BaseSettings):
+    BASE_PATH: Union[str, Path]
+    HOST: str = "localhost"
+    PORT: str = "8000"
+    BASE_URL: str = "http://localhost:8000"
+    BASE_DOMAIN: str = "localhost"
+    DATABASES: Dict[str, Database] = {}
+    REDIS: Optional[RedisDsn] = None
+    REDIS_POOL_SIZE: int = 10
+    TEMPLATES_DIR: List[str] = []
+    TEMPLATES_PACKAGE_NAME: Optional[str] = None
+    DEV_MODE: bool = False
+    SECURITY: SecurityConfig = SecurityConfig(secret_key=os.urandom(16).hex())
+    AUTHENTICATORS: List[str] = []
+    CUSTOM_COMMANDS: List[str] = []
+    USER_ENDPOINTS: bool = True
+    USER_DB: str = "default"
+    COMMANDS: List[str] = []
+    TASKS: Optional[TasksBackend] = None
+
+    APPS: List[str] = []
+
+    # web
+    STATIC_URL: str = ""
+    STATICFILES_DIRS: List[StaticDir] = Field([])
+    VITE_ENABLED: bool = False
+    VITE_CONFIG: ViteConfig = ViteConfig()
+    # logs
+    LOGLEVEL: str = "INFO"
+    LOGCONFIG: Dict[str, Any] = {}
+    DEBUG: bool = False
+
+    STORAGE: Optional[Dict[str, Storage]] = None
+
+    # MIGRATIONS: Dict[str, Migration] = {}
+
+    CORS_ORIGINS: Union[List[str], str] = "*"
+    CORS_ALLOW_HEADERS: Union[List[str], str] = "*"
+    SANIC_APP_NAME: str = defaults.SANIC_APP
+    SINGLE_PROCESS: bool = False
+    SETTINGS_MODULE: Optional[str] = None
+
+    class Config:
+        env_prefix = "SRV_"
+        smart_union = True
+
+
 class UserLogin(BaseModel):
     username: str
     password: str
@@ -222,9 +260,68 @@ class TokenCreds(BaseModel):
         extra = "forbid"
 
 
+class DefaultMeta(BaseModel):
+    keywords: Optional[str] = None
+    description: Optional[str] = None
+    author: Optional[str] = None
+    viewport: str = "width=device-width, initial-scale=1.0, maximum-scale=1"
+
+
+class OGMeta(BaseModel):
+    title: str
+    description: str
+    url: str
+    image: str
+    type_: str = "website"
+
+
 class HtmlData(BaseModel):
     # navbar: List[MenuOption]
     ctx: Dict[str, Any]
     title: str
-    content: Dict[str, Any]
-    meta: Optional[Dict[str, str]] = None
+    content: Dict[str, Any] = Field({})
+    lang: str = "en"
+    meta: DefaultMeta = Field(DefaultMeta())
+    og: Optional[OGMeta] = None
+
+
+class Cookie(BaseModel):
+    """
+    expires: datetime - The time for the cookie to expire on the client’s browser.
+
+    :param max_age:  Number of seconds the cookie should live for.
+    :param path: The subset of URLs to which this cookie applies. Defaults to /.
+    :param domain: Specifies the domain for which the cookie is valid.
+        An explicitly specified domain must always start with a dot.
+    :param max_age: Number of seconds the cookie should live for.
+    :param secure: Specifies whether the cookie will only be sent
+        via HTTPS.
+    :param httponly: Specifies whether the cookie cannot be read by JavaScript.
+    :param samesite: Default is browser dependent, specification states
+        (Lax, Strict, and None) are valid values.
+    """
+
+    value: str
+    domain: str
+    httponly: bool = True
+    path: str = "/"
+    secure: bool = True
+    samesite: str = "lax"
+    max_age: int = Field(alias="max-age", default=60 * 60)
+
+
+class Bucket(BaseModel):
+    name: str
+    url: str
+    storage_class: str
+    location: str
+    versioning: bool = False
+    labels: Optional[Dict[str, str]] = None
+    public: bool = False
+    created_at: Optional[datetime] = None
+
+    def __repr__(self):
+        return f"<Bucket {self.name}>"
+
+    def __str__(self):
+        return f"<Bucket {self.name}>"
